| Title: | Connection to the GeneNetwork API |
|---|---|
| Description: | Tools for connecting to the GeneNetwork API. |
| Authors: | Karl W Broman [aut, cre]
|
| Maintainer: | Karl W Broman <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.3-8 |
| Built: | 2026-06-07 21:08:26 UTC |
| Source: | https://github.com/rqtl/GNapi |
Check if GeneNetwork is live
check_gn(url = gnapi_url())check_gn(url = gnapi_url())
url |
URL for GeneNetwork |
Character string.
check_gn()check_gn()
Get genotype data
get_geno(group, url = gnapi_url(), format = "geno")get_geno(group, url = gnapi_url(), format = "geno")
group |
Name of group |
url |
The URL for the GeneNetwork API |
format |
The group's genotypes format |
A data frame
g <- get_geno("QSM")g <- get_geno("QSM")
Get phenotype data
get_pheno(dataset, trait = NULL, url = gnapi_url())get_pheno(dataset, trait = NULL, url = gnapi_url())
dataset |
Short abbreviation for a dataset, or name of a group |
trait |
Optional trait name |
url |
The URL for the GeneNetwork API |
A data frame, with samples as rows and either traits as columns or with the columns being detailed information for a single trait
ph1 <- get_pheno("BXDPublish") ph2 <- get_pheno("BXD", "10002") ph3 <- get_pheno("HC_M2_0606_P", "1436869_at")ph1 <- get_pheno("BXDPublish") ph2 <- get_pheno("BXD", "10002") ph3 <- get_pheno("HC_M2_0606_P", "1436869_at")
The current URL for the GeneNetwork API
gnapi_url()gnapi_url()
The URL, as character string
gnapi_url()gnapi_url()
Get summary information about a phenotype
info_pheno(group, trait, url = gnapi_url())info_pheno(group, trait, url = gnapi_url())
group |
Name of a group of datasets |
trait |
Trait identifier (can be a vector) |
url |
The URL for the GeneNetwork API |
A data frame
info_pheno("BXD", "10002") info_pheno("HC_M2_0606_P", "1436869_at")info_pheno("BXD", "10002") info_pheno("HC_M2_0606_P", "1436869_at")
List available datasets for a group.
list_datasets(group = NULL, dataset = NULL, url = gnapi_url())list_datasets(group = NULL, dataset = NULL, url = gnapi_url())
group |
Name of group, as single character string |
dataset |
Optional name of a specific dataset |
url |
URL for GeneNetwork API |
A data frame with dataset ID, name, and description
list_datasets("BXD") list_datasets("BXD", "HC_M2_0606_P") list_datasets(dataset="HC_M2_0606_P") g <- list_groups() d <- list_datasets(g$Name[8]) list_datasets(dataset=d$Short_Abbreviation[1]) list_datasets("bxd", "10001")list_datasets("BXD") list_datasets("BXD", "HC_M2_0606_P") list_datasets(dataset="HC_M2_0606_P") g <- list_groups() d <- list_datasets(g$Name[8]) list_datasets(dataset=d$Short_Abbreviation[1]) list_datasets("bxd", "10001")
Get list of available groups
list_groups(species = NULL, url = gnapi_url())list_groups(species = NULL, url = gnapi_url())
species |
Optional species name, for just the groups for that species. |
url |
URL for GeneNetwork API |
Data frame with columns FullName, Id, Name, and TaxonomyId.
list_species(), list_datasets()
list_groups() list_groups("barley")list_groups() list_groups("barley")
Get list of available species
list_species(species = NULL, url = gnapi_url())list_species(species = NULL, url = gnapi_url())
species |
Optional character string, to obtain a particular, single species |
url |
URL for GeneNetwork API |
Data frame with columns FullName, Id, Name, and TaxonomyId.
list_groups(), list_datasets()
list_species()list_species()
Find correlated traits in GeneNetwork
run_correlation( dataset, group, trait, type = c("sample", "tissue"), method = c("pearson", "spearman"), n_results = 500, url = gnapi_url() )run_correlation( dataset, group, trait, type = c("sample", "tissue"), method = c("pearson", "spearman"), n_results = 500, url = gnapi_url() )
dataset |
Name of database for the trait ( |
group |
Target database name to be correlated against |
trait |
ID for trait used for correlation |
type |
Sample or tissue correlation |
method |
Pearson or Spearman correlation |
n_results |
Number of results to return |
url |
The URL for the GeneNetwork API |
Data frame
out <- run_correlation("HC_M2_0606_P", "BXDPublish", "1427571_at")out <- run_correlation("HC_M2_0606_P", "BXDPublish", "1427571_at")
Perform a genome scan using gemma
run_gemma(dataset, trait, use_loco = FALSE, maf = 0.01, url = gnapi_url())run_gemma(dataset, trait, use_loco = FALSE, maf = 0.01, url = gnapi_url())
dataset |
ID for dataset being used ( |
trait |
ID for trait being mapped |
use_loco |
Whether to use LOCO (leave one chromosome out) |
maf |
Filter on minor allele frequency |
url |
The URL for the GeneNetwork API |
A data frame
out <- run_gemma("HC_M2_0606_P", "1418701_at")out <- run_gemma("HC_M2_0606_P", "1418701_at")
Perform a genome scan using R/qtl
run_rqtl( dataset, trait, method = c("hk", "ehk", "em", "imp", "mr", "mr-imp", "mr-argmax"), model = c("normal", "binary", "2part", "np"), n_perm = 0, control_marker = NULL, interval_mapping = FALSE, url = gnapi_url() )run_rqtl( dataset, trait, method = c("hk", "ehk", "em", "imp", "mr", "mr-imp", "mr-argmax"), model = c("normal", "binary", "2part", "np"), n_perm = 0, control_marker = NULL, interval_mapping = FALSE, url = gnapi_url() )
dataset |
ID for dataset being used ( |
trait |
ID for trait being mapped |
method |
Indicates whether to use the EM algorithm, imputation, Haley-Knott regression, the extended Haley-Knott method, or marker regression. |
model |
The phenotype model: the usual normal model, a model for binary traits, a two-part model, or non-parametric analysis |
n_perm |
Number of permutations |
control_marker |
Name of marker to use as a covariate |
interval_mapping |
Whether to use interval mapping |
url |
The URL for the GeneNetwork API |
A data frame
out <- run_rqtl("HC_M2_0606_P", "1418701_at")out <- run_rqtl("HC_M2_0606_P", "1418701_at")